@@ -3,6 +3,7 @@ from copulas.univariate.beta import BetaUnivariate
 from copulas.univariate.gamma import GammaUnivariate
 from copulas.univariate.gaussian import GaussianUnivariate
 from copulas.univariate.gaussian_kde import GaussianKDE
+from copulas.univariate.log_laplace import LogLaplace
 from copulas.univariate.student_t import StudentTUnivariate
 from copulas.univariate.truncated_gaussian import TruncatedGaussian
 from copulas.univariate.uniform import UniformUnivariate
@@ -17,5 +18,6 @@ __all__ = (
     'Univariate',
     'ParametricType',
     'BoundedType',
-    'UniformUnivariate'
+    'UniformUnivariate',
+    'LogLaplace'
 )
