@@ -35,3 +35,6 @@ class BetaUnivariate(ScipyModel):
 
     def _is_constant(self):
         return self._params['scale'] == 0
+
+    def _extract_constant(self):
+        return self._params['loc']
